/*
 * Copyright (C) 2010 Canonical, Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier.tilloy@canonical.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; version 3.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef QT_BAMF_FACTORY_H
#define QT_BAMF_FACTORY_H

#include <QtCore/QObject>
#include <QtCore/QHash>

class BamfView;

class __attribute__ ((visibility ("default"))) BamfFactory: public QObject
{
    Q_OBJECT

public:
    static BamfFactory& get_default()
    {
        static BamfFactory instance;
        return instance;
    }

    BamfView * view_for_path(QString path);

private:
    BamfFactory();
    BamfFactory(BamfFactory const&);
    void operator=(BamfFactory const&);

    QHash<QString, BamfView*> *m_views;

private Q_SLOTS:
    void OnViewDestroyed(QObject *view);
    void OnViewClosed();
};

#endif

